jQuery(document).ready(function ($) {

  // Abilita il drag and drop
  $('.quick-note').draggable({
    stop: function (event, ui) {
      var noteId = $(this).data('note-id');
      var left = ui.position.left;
      var top = ui.position.top;

      // Salva la nuova posizione
      updateNotePosition(noteId, left, top);

      // Regola l'altezza solo se necessario
      adjustContainerHeight();
    }
  });
  // Funzione per abilitare il resize per ogni nota
  $('.quick-note').resizable({
    minWidth: 100, // Imposta la larghezza minima
    minHeight: 100, // Imposta l'altezza minima
    stop: function (event, ui) {
      var noteId = $(this).data('note-id');
      var width = ui.size.width;
      var height = ui.size.height;

      // Salva la nuova dimensione
      updateNoteSize(noteId, width, height);

      // Regola l'altezza solo se necessario
      adjustContainerHeight();
    }
  });

 
  // Gestisci la cancellazione delle note
  $('.delete-note').click(function () {
    if (confirm('Are you sure you want to delete this note?')) {
      var noteId = $(this).closest('.quick-note').data('note-id');
      var noteElement = $(this).closest('.quick-note');

      $.ajax({
        url: ajaxurl,
        method: 'POST',
        data: {
          action: 'delete_quick_note',
          note_id: noteId,
        },
        success: function (response) {
          if (response.success) {
            noteElement.fadeOut(400, function () {
              $(this).remove();
              adjustContainerHeight(); // Regola l'altezza dopo la rimozione
            });
          } else {
            alert('Errore: ' + response.data.message);
          }
        },
        error: function () {
          alert('Si è verificato un errore imprevisto durante l\'eliminazione della nota.');
        }
      });
    }
  });


  // Funzione per calcolare l'altezza totale delle note visibili nel contenitore
  function adjustContainerHeight() {
    var container = $('#quick-notes-container');
    var containerTop = container.offset().top;
    var containerHeight = 0;

    // Calcola l'altezza massima solo per le note all'interno del contenitore
    container.find('.quick-note').each(function () {
      var noteOffset = $(this).offset();
      var noteHeight = $(this).outerHeight(true); // Altezza della nota inclusi margini

      // Verifica se la nota si trova nel contenitore
      if (
        noteOffset.left >= container.offset().left
        && noteOffset.left + $(this).outerWidth() <= container.offset().left + container.outerWidth()
      ) {
        var noteBottom = noteOffset.top + noteHeight;
        if (noteBottom > containerTop) {
          containerHeight = Math.max(containerHeight, noteBottom - containerTop);
        }
      }
    });

    // Imposta l'altezza del contenitore
    container.height(containerHeight > 0 ? containerHeight : 'auto');
  }

  // Regola l'altezza del contenitore al caricamento della pagina
  adjustContainerHeight();

  // Gestisci l'aggiunta di una nuova nota
 $('#add-note-form').submit(function (e) {
    e.preventDefault();
    // Verifica il numero di note attuali
    if (currentNoteCount >= quickNotesLimit) {
        // Sostituisci il form con il messaggio per la versione PRO
        $('#add-note-form').replaceWith(`
            <div class="alert alert-warning mt-3">
                <p>You can only add 2 notes in the free version. Upgrade to the PRO version to unlock unlimited notes and other advanced features!</p>
                <a target="_blank" href="https://www.xpertplugins.com/prodotto/dashboard-quick-notes/" class="btn btn-primary">Discover the PRO version</a>
            </div>
        `);
        return; // Esci dalla funzione per evitare ulteriori azioni
    }

    // Recupera il contenuto dall'editor TinyMCE
    var noteContent = tinymce.get('note-editor').getContent();

    // ID unico per la nota
    var noteId = new Date().getTime();
    var note = $('<div class="quick-note card mb-3 p-3" data-note-id="' + noteId + '">')
        .html(noteContent) // Inserisce il contenuto con la formattazione dell'editor
        .draggable({
            containment: "document",
            stop: function (event, ui) {
                var left = ui.position.left;
                var top = ui.position.top;
                updateNotePosition(noteId, left, top);

                // Regola l'altezza solo se necessario
                adjustContainerHeight();
            }
        });

    // Aggiungi la nota al contenitore
    $('#quick-notes-container').append(note);

    // Incrementa il contatore delle note
    currentNoteCount++;

    // Controlla di nuovo il limite dopo aver aggiunto la nota
    if (currentNoteCount >= quickNotesLimit) {
        // Sostituisci il form con il messaggio per la versione PRO
        $('#add-note-form').replaceWith(`
            <div class="alert alert-warning mt-3">
                <p>You can only add 2 notes in the free version. Upgrade to the PRO version to unlock unlimited notes and other advanced features!</p>
                <a href="https://tuosito.com/pro-version" class="btn btn-primary">Discover the PRO version</a>
            </div>
        `);
    }

    // Regola l'altezza del contenitore dopo l'aggiunta
    adjustContainerHeight();

    // Resetta l'editor
    tinymce.get('note-editor').setContent('');
});


  // Funzione per aggiornare la posizione della nota (AJAX)
  function updateNotePosition(noteId, left, top) {
    $.post(ajaxurl, {
      action: 'update_note_position',
      note_id: noteId,
      left: left,
      top: top
    });
  }
  // Gestisce il clic sui pallini colorati per cambiare il colore della nota
  $('.color-bullet').click(function () {
    var noteElement = $(this).closest('.quick-note');
    var newColorClass = $(this).attr('class').split(' ')[1]; // Ottieni la classe del pallino cliccato

    // Cambia il colore della nota
    noteElement.removeClass('pastel1 pastel2 pastel3 pastel4').addClass(newColorClass);

    // Salva il nuovo stato nel database (usando AJAX)
    var noteId = noteElement.data('note-id');
    $.post(ajaxurl, {
      action: 'update_note_color',
      note_id: noteId,
      color: newColorClass
    });
  });

});
