<?php
/*
Plugin Name: Quick Notes Free
Plugin URI: https://www.xpertplugins.com/prodotto/dashboard-quick-notes/
Description: Allows you to add quick notes to your WordPress dashboard.
Version: 1.0
Author: Maddalena Furfaro
Author URI: https://xpertplugins.com
License: GPL2
*/


// Aggiungi il CSS e JS necessari per la dashboard
function quick_notes_assets( $hook ) {
  if ( 'index.php' != $hook ) return;

  // Aggiungi Bootstrap
wp_enqueue_style('bootstrap-css', plugin_dir_url(__FILE__) . 'assets/css/bootstrap.min.css');
wp_enqueue_script('bootstrap-js', plugin_dir_url(__FILE__) . 'assets/js/bootstrap.bundle.min.js', array('jquery'), null, true);

  // Carica il CSS personalizzato
  wp_enqueue_style( 'quick-notes-style', plugin_dir_url( __FILE__ ) . 'assets/css/quick-notes.css' );
  wp_enqueue_style( 'quick-notes-icons', plugin_dir_url( __FILE__ ) . 'assets/css/all.min.css' );
  wp_enqueue_script( 'quick-notes-js', plugin_dir_url( __FILE__ ) . 'assets/js/quick-notes.js', array( 'jquery', 'jquery-ui-draggable' ), null, true );

  // Carica TinyMCE per l'editor rich text
  wp_enqueue_script( 'editor' );
  wp_enqueue_script( 'wp-tinymce' );
  wp_enqueue_style( 'wp-editor' );
  wp_enqueue_media(); // Carica il Media Manager
  // Carica il CSS e il JS di jQuery UI
  wp_enqueue_script( 'jquery-ui-resizable' );
}
add_action( 'admin_enqueue_scripts', 'quick_notes_assets' );

// Aggiungi il widget delle note alla bacheca
function quick_notes_dashboard_widgets() {
  wp_add_dashboard_widget(
    'quick_notes_widget', // ID del widget
    'Quick Notes', // Titolo del widget
    'quick_notes_display' // Funzione che mostra il contenuto
  );
}
add_action( 'wp_dashboard_setup', 'quick_notes_dashboard_widgets' );

// Funzione che mostra il contenuto del widget
function quick_notes_display() {
    
  ?>
<div id="quick-notes-container" class="container-fluid" style="position: relative;">
  <?php
  $user_id = get_current_user_id();
  $notes = get_user_meta( $user_id, '_quick_notes', true );
// Conta le note attuali
   $note_count = count($notes);
	
  if ( !empty( $notes ) ) {
    foreach ( $notes as $note ) {
      // Determina il colore della nota
      $color_class = isset( $note[ 'color' ] ) ? $note[ 'color' ] : 'pastel1'; // Colore di default
      $note_expiration = $note[ 'note_expiration' ];
      $note_date = gmdate('d-m-Y', strtotime($note['date']));

      $note_author = isset($note['author']) ? $note['author'] : 'Sconosciuto'; // Default se manca l'autore

     echo "<div data-expiration='" . esc_attr($note_expiration) . "' 
      class='quick-note card mb-3 p-3 " . esc_attr($color_class) . "' 
      data-note-id='" . esc_attr($note['id']) . "' 
      style='position: absolute; left: " . esc_attr($note['position']['left']) . "px; top: " . esc_attr($note['position']['top']) . "px;'>
        <div class='note-header d-flex justify-content-between align-items-center'>
            <div class='note-meta-top'>
                <span class='note-date text-muted me-2'><i class='fas fa-calendar-alt'></i> " . esc_html($note_date) . "</span>
            </div>
            <div class='note-actions'>";
if (!empty($note_expiration) && strtotime($note_expiration) < time()) {
    echo '<span class="note-expired-icon" title="' . esc_attr__('Nota scaduta', 'quick-notes-free') . '">❗</span>';
}
if ($note['author_id'] == get_current_user_id()) {
    echo "<button class='btn btn-sm btn-warning edit-note me-2' title='" . esc_attr__('Modifica', 'quick-notes-free') . "'>
          <i class='fas fa-edit'></i>
          </button>";
}
echo "<button class='btn btn-sm btn-danger delete-note' title='" . esc_attr__('Elimina', 'quick-notes-free') . "'>
      <i class='fas fa-trash-alt'></i>
      </button>
            </div>
        </div>
        <div class='note-content' id='" . esc_attr('note-content-' . $note['id']) . "'>" . wp_kses_post($note['content']) . "</div>
        <div class='note-meta-bottom'>
            <span class='note-author'><i class='fas fa-user'></i> " . esc_html($note_author) . "</span>
        </div>
        <div class='color-bullets'>
            <span class='color-bullet pastel1'></span>
            <span class='color-bullet pastel2'></span>
            <span class='color-bullet pastel3'></span>
            <span class='color-bullet pastel4'></span>
        </div>
    </div>";

    }
  }
  ?>
</div>
<h2>Add new Note:</h2>
<?php if ($note_count < 2): ?>
<form action="admin-post.php" method="POST">
  <input type="hidden" name="action" value="add_quick_note">
  <textarea name="note_content" rows="10" cols="50" id="note-editor" class="form-control note-editor" placeholder="Write note..."></textarea>
	<div class="note-settings">
    <label for="note-expiration">Expiration:</label>
    <input type="datetime-local" class="note-expiration" name="note-expiration">
</div>

  <br>
  <input type="submit" class="btn btn-primary mt-2" value="Add note">
</form>

<!-- Pulsante per salvare la modifica (solo visibile dopo il click su modifica) -->
<button class="btn btn-success save-note" style="display:none;">Save note</button>
 <?php else: ?>
        <div class="alert alert-warning mt-3">
            <p>You can only add 2 notes in the free version. Upgrade to the PRO version to unlock unlimited notes and other advanced features!</p>
            <a target="_blank" href="https://www.xpertplugins.com/prodotto/dashboard-quick-notes/" class="btn btn-primary">Discover the PRO version</a>
        </div>
    <?php endif; ?>
<div id="pro-modal" class="modal fade" tabindex="-1" role="dialog">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Upgrade to the PRO version</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Chiudi"></button>
            </div>
            <div class="modal-body">
                <p>The editing function is only available in the PRO version of the plugin. Upgrade to the PRO version to unlock this feature and more!</p>
                <a target="_blank" href="https://www.xpertplugins.com/prodotto/dashboard-quick-notes/" class="btn btn-primary">Discover the PRO version</a>
            </div>
        </div>
    </div>
</div>

<script type="text/javascript">
        jQuery(document).ready(function($) {
    // Inizializza l'editor TinyMCE sulla textarea
    tinymce.init({
        selector: '#note-editor',
        height: 300,
        plugins: 'lists link image media',
        toolbar: 'undo redo | bold italic | alignleft aligncenter alignright | link image media',
        menubar: false,
        image_advtab: true,
        automatic_uploads: true,

        // Configura il file picker per il Media Manager di WordPress
        file_picker_callback: function(callback, value, meta) {
            var mediaUploader;

            mediaUploader = wp.media({
                title: 'Choose or upload a media file',
                button: {
                    text: 'Inserisci nella nota'
                },
                multiple: false
            });

            mediaUploader.on('select', function() {
                var attachment = mediaUploader.state().get('selection').first().toJSON();

                if (meta.filetype === 'image') {
                    callback(attachment.url, { alt: attachment.alt });
                } else if (meta.filetype === 'media') {
                    callback(attachment.url);
                }
            });

            mediaUploader.open();
        }
    });

			 // Gestisci il click su "Modifica"
    $('.edit-note').click(function() {
        // Mostra il modal
        $('#pro-modal').modal('show');
    });
			// Gestione del salvataggio della nota
    $('.save-note').off('click').on('click', function() {
        var currentNoteId = $(this).attr('data-note-id');
        var newContent = tinymce.get('note-editor').getContent();
        var currentContentDiv = $('#note-content-' + currentNoteId);

        // Invia la modifica al server
        $.post(ajaxurl, {
            action: 'update_quick_note',
            note_id: currentNoteId,
            content: newContent
        }, function(response) {
            if (response.success) {
                currentContentDiv.html(newContent);
                alert('Note updated successfully!');

                // Ripristina i pulsanti
                $('.save-note').hide();
                $('input[type="submit"]').show();

                // Rimuove l'ascoltatore
                $(document).off('click.dismissEdit');
            } else {
                alert('Errore nel salvataggio della nota.');
            }
        });
    });

});

    </script>
<?php
}


// Funzione che gestisce l'aggiunta della nota
function add_quick_note() {
  if ( isset( $_POST[ 'note_content' ] ) && !empty( $_POST[ 'note_content' ] ) ) {
    $user_id = get_current_user_id();

	  
    // Usa wp_kses_post per permettere l'HTML sicuro
    $note_content = wp_kses_post( wp_unslash($_POST[ 'note_content' ] ));
    $note_id = uniqid();
    $date = current_time( 'mysql' );
    $author = wp_get_current_user()->display_name;
	$expiration = isset( $_POST['note-expiration'] ) ? sanitize_text_field( wp_unslash( $_POST['note-expiration'] ) ) : '';
      // Salvataggio della nota
    $notes = get_user_meta( $user_id, '_quick_notes', true );
    if ( !is_array( $notes ) ) {
      $notes = [];
    }
    $notes[] = [
      'id' => $note_id,
      'content' => $note_content,
      'date' => $date,
      'author' => $author,
	  'author_id' => get_current_user_id(), // Aggiungi l'autore
      'status' => false, // Non validata inizialmente
      'position' => [ 'left' => 0, 'top' => 0 ], // Posizione iniziale
	  'note_expiration'	=> $expiration
    ];
    update_user_meta( $user_id, '_quick_notes', $notes );
	 
	 
  }
  wp_redirect( admin_url( 'index.php' ) );
  exit;
}

add_action( 'admin_post_add_quick_note', 'add_quick_note' );

// Funzione per eliminare una nota
function delete_quick_note() {
  if ( isset( $_POST[ 'note_id' ] ) ) {
    $user_id = get_current_user_id();
    $note_id = sanitize_text_field( $_POST[ 'note_id' ] );

    // Recupera le note dell'utente
    $notes = get_user_meta( $user_id, '_quick_notes', true );
    if ( is_array( $notes ) ) {
      // Filtra le note per eliminare quella con l'ID corrispondente
      $notes = array_filter( $notes, function ( $note )use( $note_id ) {
        return $note[ 'id' ] !== $note_id;
      } );

      // Aggiorna il meta utente
      update_user_meta( $user_id, '_quick_notes', $notes );

      wp_send_json_success( [ 'message' => 'Note successfully deleted' ] );
    }
  }

  wp_send_json_error( [ 'message' => 'Errore durante l\'eliminazione della nota' ] );
}
add_action( 'wp_ajax_delete_quick_note', 'delete_quick_note' );

function update_note_position() {
  // Verifica che l'utente abbia i permessi
  if ( !current_user_can( 'edit_posts' ) ) {
    wp_send_json_error( [ 'message' => 'Permesso negato.' ] );
  }

  // Verifica che i dati necessari siano presenti
  if ( isset( $_POST[ 'note_id' ], $_POST[ 'left' ], $_POST[ 'top' ] ) ) {
    $user_id = get_current_user_id();
    $note_id = sanitize_text_field( $_POST[ 'note_id' ] );
    $left = intval( $_POST[ 'left' ] );
    $top = intval( $_POST[ 'top' ] );

    // Recupera le note dell'utente
    $notes = get_user_meta( $user_id, '_quick_notes', true );

    if ( is_array( $notes ) ) {
      foreach ( $notes as & $note ) {
        if ( $note[ 'id' ] === $note_id ) {
          // Aggiorna la posizione della nota
          $note[ 'position' ] = [
            'left' => $left,
            'top' => $top,
          ];
          break;
        }
      }

      // Salva le note aggiornate
      update_user_meta( $user_id, '_quick_notes', $notes );
      wp_send_json_success( [ 'message' => 'Posizione aggiornata con successo.' ] );
    }
  }

  wp_send_json_error( [ 'message' => 'Errore durante l\'aggiornamento della posizione.' ] );
}
add_action( 'wp_ajax_update_note_position', 'update_note_position' );


function update_note_size() {
  // Verifica che l'utente abbia i permessi
  if ( !current_user_can( 'edit_posts' ) ) {
    wp_send_json_error( [ 'message' => 'Permesso negato.' ] );
  }

  // Verifica che i dati necessari siano presenti
  if ( isset( $_POST[ 'note_id' ], $_POST[ 'width' ], $_POST[ 'height' ] ) ) {
    $user_id = get_current_user_id();
    $note_id = sanitize_text_field( $_POST[ 'note_id' ] );
    $width = intval( $_POST[ 'width' ] );
    $height = intval( $_POST[ 'height' ] );

    // Recupera le note dell'utente
    $notes = get_user_meta( $user_id, '_quick_notes', true );

    if ( is_array( $notes ) ) {
      foreach ( $notes as & $note ) {
        if ( $note[ 'id' ] === $note_id ) {
          // Aggiorna la dimensione della nota
          $note[ 'size' ] = [
            'width' => $width,
            'height' => $height,
          ];
          break;
        }
      }

      // Salva le note aggiornate
      update_user_meta( $user_id, '_quick_notes', $notes );
      wp_send_json_success( [ 'message' => 'Dimensione aggiornata con successo.' ] );
    }
  }

  wp_send_json_error( [ 'message' => 'Errore durante l\'aggiornamento della dimensione.' ] );
}
add_action( 'wp_ajax_update_note_size', 'update_note_size' );

// Funzione per aggiornare il contenuto della nota
function update_quick_note() {
  // Verifica che l'utente abbia i permessi
  if ( !current_user_can( 'edit_posts' ) ) {
    wp_send_json_error( [ 'message' => 'Permesso negato.' ] );
  }

  // Verifica che i dati necessari siano presenti
  if ( isset( $_POST[ 'note_id' ], $_POST[ 'content' ] ) ) {
    $user_id = get_current_user_id();
    $note_id = sanitize_text_field( $_POST[ 'note_id' ] );
    $new_content = wp_kses_post( $_POST[ 'content' ] );

    // Recupera le note dell'utente
    $notes = get_user_meta( $user_id, '_quick_notes', true );

    if ( is_array( $notes ) ) {
      foreach ( $notes as & $note ) {
        if ( $note[ 'id' ] === $note_id ) {
          // Aggiorna il contenuto della nota
          $note[ 'content' ] = $new_content;
          break;
        }
      }

      // Salva le note aggiornate
      update_user_meta( $user_id, '_quick_notes', $notes );
      wp_send_json_success( [ 'message' => 'Note updated successfully.' ] );
    }
  }

  wp_send_json_error( [ 'message' => 'Error updating note.' ] );
}
add_action( 'wp_ajax_update_quick_note', 'update_quick_note' );

function update_note_color() {
  // Verifica che l'utente abbia i permessi
  if ( !current_user_can( 'edit_posts' ) ) {
    wp_send_json_error( [ 'message' => 'Permesso negato.' ] );
  }

  // Verifica che i dati necessari siano presenti
  if ( isset( $_POST[ 'note_id' ], $_POST[ 'color' ] ) ) {
    $user_id = get_current_user_id();
    $note_id = sanitize_text_field( $_POST[ 'note_id' ] );
    $color = sanitize_text_field( $_POST[ 'color' ] );

    // Recupera le note dell'utente
    $notes = get_user_meta( $user_id, '_quick_notes', true );

    if ( is_array( $notes ) ) {
      foreach ( $notes as & $note ) {
        if ( $note[ 'id' ] === $note_id ) {
          // Aggiorna il colore della nota
          $note[ 'color' ] = $color;
          break;
        }
      }

      // Salva le note aggiornate
      update_user_meta( $user_id, '_quick_notes', $notes );
      wp_send_json_success( [ 'message' => 'Color updated successfully.' ] );
    }
  }

  wp_send_json_error( [ 'message' => 'Errore durante l\'aggiornamento del colore.' ] );
}
add_action( 'wp_ajax_update_note_color', 'update_note_color' );
